#
# spec file for package postfixadmin
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           postfixadmin
Version:        3.0
Release:        2.4
Url:            http://postfixadmin.sourceforge.net/
Source0:        http://sourceforge.net/projects/postfixadmin/files/postfixadmin/%{name}-%{version}/%{name}-%{version}.tar.gz

BuildArch:      noarch

# Web interface
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_ver}
  # Requires:   mod_php_any # no idea in which fedora package mod_php5 is...
Requires:       php_database
%else
Requires:       mod_php_any
Requires:       php_any_db
Recommends:     php-mysql
%endif

Requires:       /usr/sbin/sendmail
Requires:       php-mbstring
Requires:       php-spl

# test/*, xmlrpc.php, squirrelmail plugin
# big dependency, not needed by all users - therefore no hard Requirement
%if 0%{?suse_version}
Recommends:     php5-ZendFramework < 2.0
%endif

# vacation.pl
Requires:       perl(DBI)
Requires:       perl(Email::Valid)
Requires:       perl(Encode)
Requires:       perl(Getopt::Std)
Requires:       perl(Log::Log4perl)
Requires:       perl(MIME::Base64)
Requires:       perl(MIME::EncWords)
Requires:       perl(Mail::Sender)
Requires:       perl(strict)

# cleanupdirs.pl
Requires:       perl(File::Path)
Requires:       perl(Getopt::Long)
# mkeveryone.pl
Requires:       perl(Fcntl)
Requires:       perl(IO)
Requires:       perl(IO::File)
Requires:       perl(POSIX)
Requires:       perl(Time::Local)
# fetchmail.pl
Requires:       perl(File::Temp)
Requires:       perl(LockFile::Simple)
Requires:       perl(Sys::Syslog)

%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_ver}
# create vacation user/group
PreReq:         shadow-utils
BuildRequires:  httpd-devel
#define serverroot %(/usr/sbin/apxs -q datadir 2>/dev/null || /usr/sbin/apxs -q PREFIX)/htdocs/
%define serverroot /var/www/html/
%define apache_group apache
%else
# create vacation user/group
PreReq:         pwdutils
BuildRequires:  apache2-devel
%define serverroot %(/usr/sbin/apxs2 -q datadir 2>/dev/null || /usr/sbin/apxs2 -q PREFIX)/htdocs/
%define apache_group www
Recommends:     postfix
Suggests:       php-pgsql
%endif

%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_ver}
# Do not check any files in ADDITIONS for Requires, see https://fedoraproject.org/wiki/Packaging:AutoProvidesAndRequiresFiltering
%global __requires_exclude_from ^%{_prefix}/lib/%{name}/ADDITIONS/.*$
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Summary:        Web-based management tool for Postfix virtual domains, mailboxes and aliases
License:        GPL-2.0+
Group:          Productivity/Networking/Web/Frontends

%description
PostfixAdmin is a PHP based application that handles Postfix Style Virtual Domains and
Users that are stored in MySQL or PostgreSQL.

Postfix Admin supports:
- Virtual Mailboxes / Virtual Aliases / Forwarders
- Alias domains (Domain to Domain forwarding with recipient validation)
- Vacation (auto-response) for Virtual Mailboxes.
- Quota / Alias & Mailbox limits per domain.
- Fetchmail integration
- Packaged with over 25 languages.

%prep
%setup -q

%build
echo "*** serverroot: %{serverroot} ***"

%install
mkdir -p -m0755 %{buildroot}%{_sysconfdir}/%{name}
#mkdir -p -m0755 %{buildroot}%{_datadir}/%{name}
mkdir -p -m0755 %{buildroot}%{serverroot}/%{name}
mkdir -p -m0755 %{buildroot}%{_localstatedir}/spool/vacation
mkdir -p -m0755 %{buildroot}/%{_prefix}/lib/%{name}

# install the config files
#install -m 0640 config.inc.php.sample %{buildroot}%{_sysconfdir}/%{name}/config.inc.php
#ln -s ../../../..%{_sysconfdir}/%{name}/config.inc.php \
#    %{buildroot}%{_datadir}/%{name}/config.inc.php

install -m 0644 *.php *.js %{buildroot}%{serverroot}/%{name}/

mv VIRTUAL_VACATION/vacation.pl %{buildroot}%{_prefix}/lib/%{name}/
# compatibility symlink to match documentation
( cd %{buildroot}%{_localstatedir}/spool/vacation/ && ln -s ../../../usr/lib/%{name}/vacation.pl )

# copy over the rest
for d in configs css images languages model scripts smarty templates users ; do
    cp -rp $d %{buildroot}%{serverroot}/%{name}/
done
chmod 755 %{buildroot}%{serverroot}/%{name}/scripts/postfixadmin-cli

install -d %{buildroot}%{serverroot}/%{name}/templates_c

# remove files related to debian packaging (to avoid it's copied as %doc)
rm -r ADDITIONS/squirrelmail-plugin/debian/
cp -rp ADDITIONS %{buildroot}%{_prefix}/lib//%{name}/
chmod 755 %{buildroot}%{_prefix}/lib/%{name}/ADDITIONS/*.{pl,sh,py} %{buildroot}%{_prefix}/lib/%{name}/ADDITIONS/squirrelmail-plugin/locale/build.sh

# install the config file
#mkdir -p %{buildroot}%{_sysconfdir}/apache2/conf.d
#install -m 644 $RPM_SOURCE_DIR/%{name}.conf \
#   %{buildroot}%{_sysconfdir}/apache2/conf.d/

%pre
%{_sbindir}/groupadd -r vacation 2> /dev/null || :
%{_sbindir}/useradd -c "Virtual Vacation" -d %{_localstatedir}/spool/vacation -s /sbin/nologin -M -r -g vacation vacation 2> /dev/null || :
# fix group for vacation user (if created by older versions (< 2012-02-13) of this package, it was created with group users)
%{_sbindir}/usermod -g vacation vacation 2> /dev/null || :

#if [ -z "`grep vacation /etc/postfix/master.cf 2>/dev/null`" ]; then
#cat <<'EOF' >>/etc/postfix/master.cf
## Postfix Admin Vacation
#vacation	unix	-	n	n	-	-	pipe
#	flags=Rq user=vacation argv=/usr/lib/postfixadmin/vacation.pl -f ${sender} -- ${recipient}
#EOF
#fi

#%preun
#if [ $1 = 0 ]; then
#    /usr/sbin/userdel vacation 2>/dev/null || :
#fi

%files
%defattr(-,root,root)
#%config %dir %{_sysconfdir}/%{name}
#%attr(640,root,www) %config(noreplace) %{_sysconfdir}/%{name}/*.php
#%config(noreplace) %{_sysconfdir}/apache2/conf.d/*.conf
%doc DOCUMENTS/* *.TXT VIRTUAL_VACATION
%{serverroot}/%{name}/
%attr(770,root,%{apache_group}) %dir %{serverroot}/%{name}/templates_c/
%dir %{_prefix}/lib/%{name}/
%{_prefix}/lib/%{name}/ADDITIONS/
%attr( 750,root,vacation)       %{_prefix}/lib/%{name}/vacation.pl
%attr(1770,root,vacation) %dir %{_localstatedir}/spool/vacation
%{_localstatedir}/spool/vacation/vacation.pl

%changelog
* Sun Sep 11 2016 suse-beta@cboltz.de
- update to PostfixAdmin 3.0:
  - add sqlite backend option
  - add configurable smtp helo (CONF["smtp_client"])
  - new translation: ro (Romanian)
  - language update: tw, cs, de
  - fix escaping in gen_show_status() (could be used to DOS list-virtual by
    creating a mail address with special chars)
  - add CSRF protection for POST requests
  - list.tpl: base edit/editactive/delete links in list.tpl on $RAW_item to
    avoid double escaping, and fix some corner cases
  - fix db_quota_text() for postgresql (concat() vs. ||)
  - change default date for 'created' and 'updated' columns from 0000-00-00
    (which causes problems with MySQL strict mode) to 2000-01-01
  - allow punicode even in TLDs
  - update Smarty to 3.1.29
  - add checks to login.php and cli to ensure database layout is up to date
  - whitelist '-1' as valid value for postfixadmin-cli
  - don't stripslashes() the password in pacrypt
  - various small bugfixes
- drop patch postfixadmin-upstream-fixes-r1802-1817.diff (upstream)
- add Requires: perl(Encode), needed by vacation.pl
* Wed Oct  7 2015 opensuse@cboltz.de
- add postfixadmin-upstream-fixes-r1802-1817.diff:
  fix escaping in gen_show_status() and double escaping in list.php
  (http://sourceforge.net/p/postfixadmin/bugs/356/)
* Wed Sep 30 2015 opensuse@cboltz.de
- several fixes for the Fedora and CentOS build:
  - don't scan scripts in the ADDITIONS directory to avoid adding excessive
    dependencies
  - use centos_ver instead of centos_version (which isn't available in CentOS 7)
  - change docroot to /var/www/html
  - change apache group to "apache"
* Sat Sep 26 2015 opensuse@cboltz.de
- update to PostfixAdmin 2.93 aka 3.0 beta3
  - add list.php for list view (replaces list-*.php and fixes some
    bugs they included)
  - add FetchmailHandler (replaces fetchmail.php)
  - several bugfixes and small improvements
  - see CHANGELOG.TXT for all details
* Tue Oct 28 2014 opensuse@cboltz.de
- update to PostfixAdmin 2.92 aka 3.0 beta2
  - remove upstream postfixadmin-svn.diff and postfixadmin-svn2.diff
  - additional changes over the two patches: the version number ;-)
* Mon Oct 27 2014 opensuse@cboltz.de
- add postfixadmin-svn2.diff with changes from upstream SVN (r1705):
  - add workaround for MariaDB to fix deleting aliases (bug#325)
  - $CONF[default_aliases] can now use the new domain as alias target (patch#124)
  - check that vacation start/end date are not in the past (patch#122)
  - update vacation INSTALL.TXT with more secure locations
  - update Smarty to 3.1.21
- make dependency on Zend Framework versioned - PostfixAdmin needs 1.x
  (2.x is totally different and incompatible)
* Fri Sep 12 2014 opensuse@cboltz.de
- add postfixadmin-svn.diff with changes from upstream SVN (r1689):
  - AliasHandler: don't clean goto field when making alias inactive (bug#316)
  - list-virtual: display quota even if $CONF[used_quotas] == NO (bug#307)
  - vacation.pl: fix postgresql queries in vacation.pl (bug#315)
  - fix query in AliasHandler getList which caused an empty list on some
    systems (bug#313)
  - fetchmail.pl: fix ssl extra options (cert check, cert path, fingerprint)
  - fix logging (run setup.php to fix old log entries) (bug#317)
  - fetchmail.php: change error_reporting() to exclude E_NOTICE (bug#322)
  - fr.lang translation update (patch#123)
- make postfixadmin-cli executable
* Tue May  6 2014 opensuse@cboltz.de
- update to PostfixAdmin 2.91 aka 3.0 beta1
  - new commandline client postfixadmin-cli
  - vacation start and end date
  - (nearly) complete rewrite to *Handler classes
  - smarty templates
  - and much more, see upstream CHANGELOG.TXT
* Thu Feb 20 2014 opensuse@cboltz.de
- update to PostfixAdmin 2.3.7 (bugfix release)
  changes that were not included in the package yet:
  - SECURITY: fix SQL injection in show_gen_status() (CVE-2014-2655, bnc#870434)
  - don't trim() mail address to avoid that aliases starting with a space are
    allowed. This fixes http://sourceforge.net/p/postfixadmin/bugs/210/ and
    https://sourceforge.net/p/postfixadmin/feature-requests/113/
  - update regex in check_domain() to support new, longer TLDs like .international
  - vacation.pl: encode subject
  - vacation.pl: disable use of TLS by default due to a bug in Mail::Sender 0.8.22
    (you can re-enable it with $smtp_tls_allowed)
- remove postfixadmin-2.3-branch.diff
* Sat Sep 28 2013 chris@computersalat.de
- rework pre section
  * if useradd -r then groupadd -r, too
* Thu Sep 12 2013 opensuse@cboltz.de
- add postfixadmin-2.3-branch.diff with all changes between 2.3.6 release
  and SVN r1521:
  - lt.lang, da.lang translation update
  - when enabling/disabling a mailbox, also update the corresponding alias
  - fix creating superadmin in setup.php with MariaDB (more strict SQL)
  - trim() localpart in create-mailbox to avoid mailbox names with leading space
  - mark vacation_notification.notified field as latin1 to avoid overlong index
* Wed Jan  2 2013 opensuse@cboltz.de
- update to PostfixAdmin 2.3.6 (bugfix release)
  changes that were not included in the package yet:
  - fix double inclusion of config.inc.php in setup.php
  - fix bool and date handling in fetchmail
- remove upstreamed patches
* Fri Nov 30 2012 opensuse@cboltz.de
- more cross-distributin %%if: pwdutils, php_any_db
* Mon Nov 26 2012 Ralf Lang <lang@b1-systems.de>
- require php-mbstring as setup.php reports this as a hard dependency
* Thu Jun 28 2012 opensuse@cboltz.de
- fix footer link (upstream r1402)
- focus username field in login form (upstream r1404)
- change existing vacation user (< 2012-02-13) to group vacation
* Sun Jun  3 2012 opensuse@cboltz.de
- add some %%if for cross-distribution handling
* Mon Feb 13 2012 opensuse@cboltz.de
- add vacation user to the vacation group (instead of the default "users")
* Thu Feb  9 2012 opensuse@cboltz.de
- update r1342 patch to fix SLE_10 build failure
* Thu Feb  2 2012 opensuse@cboltz.de
- add patch to display domain and mailbox description with correct
  encoding (upstream r1342)
* Thu Jan 26 2012 opensuse@cboltz.de
- update to PostfixAdmin 2.3.5 (security release)
  - fixes some SQL injections (CVE-2012-0811)
  - fixes some XSS vulnerabilities (CVE-2012-0812)
  - see CHANGELOG.TXT or bnc#741455 for details
* Sun Oct 16 2011 opensuse@cboltz.de
- include a patch with fixes since the 2.3.4 release (see
  CHANGELOG.TXT for details)
- Add PreReq: pwdutils
* Fri Sep 16 2011 opensuse@cboltz.de
- 2.3.4 release (bugfix release, see CHANGELOG.TXT for details)
* Sun Aug 28 2011 opensuse@cboltz.de
- move vacation.pl and ADDITIONS to /usr/lib/postfixadmin/
* Mon Aug  1 2011 opensuse@cboltz.de
- spec cleanup (manually + spec-cleaner)
- create vacation user
- move %%changelog to .changes
* Tue Mar 15 2011 Christian Boltz <opensuse@cboltz.de>
- 2.3.3 release
  bugfix release for 2.3.2 - see CHANGELOG.TXT for details
* Tue Aug 24 2010 Christian Boltz <opensuse@cboltz.de>
- 2.3.2 release
  bugfix release for 2.3.1 - see CHANGELOG.TXT for details
* Fri Jul  9 2010 Christian Boltz <opensuse@cboltz.de>
- 2.3.1 release
  bugfix release for 2.3 - see CHANGELOG.TXT for details
* Wed Oct 28 2009 Christian Boltz <opensuse@cboltz.de>
- 2.3 release
  Most important changes:
  * Improved Aliased domains support (no longer relying on catch-all domains) -
    Note this requires Postfix configuration changes; old configuration(s) will
    continue to work.
  * Security fix for setup.php (password required to access; setup.php can
    generate this and help you)
  * Superadmin can now setup fetchmail for all users
  * Enhanced fetchmail.pl script (file locking, syslog logging, configuration
    file etc)
  * Added dovecot quota support (documentation + viewing in Postfixadmin) for
    dovecot 1.0/1.1 and >= 1.2
  * Vacation re-notification after defineable timeout (default remains to
    notify only once)
  * Refactoring of /users (see /model) and XmlRpc interface for remote mail
    clients (E.g. squirrelmail-postfixadmin)
  * Add dovecot password support (see here)
  * Added support for courier authlib authentication flavours
    ($CONF['authlib_default_flavor'])
  * update.php should handle all database updates for you
  * Lots of small updates and random new minor features
  * bug fixes ;-)
* Thu Jul 24 2008 Christian Boltz <opensuse@cboltz.de>
- updated to 2.2.1.1 (fixed version number displayed in the footer)
* Tue Jul 22 2008 Christian Boltz <opensuse@cboltz.de>
- updated to 2.2.1 (fixes several bugs, no new features)
* Sun Jun  8 2008 Christian Boltz <opensuse@cboltz.de>
- finally created a package for the 2.2.0 release
* Fri Feb 29 2008 Christian Boltz <opensuse@cboltz.de>
- updated spec to follow the *.css move to css/
* Sun Dec  2 2007 Christian Boltz <opensuse@cboltz.de>
- updated to SVN version
- commented out several sections
- auto-detect serverroot and install PHP files etc. there
* Fri Dec 15 2006 lfarkas@lfarkas.org
- initial build
